#ifndef CONNECTION_INTERFACE_H
#define CONNECTION_INTERFACE_H

/*!
  \file
  \brief ʐMfoCX̃C^[tF[X`

  \author Satofumi KAMIMURA

  $Id$

  \todo skip() ́AɔzuׂH
*/


/*!
  \brief ʐMC^[tF[X
*/
class ConnectionInterface {
public:
  virtual ~ConnectionInterface(void) {}

  virtual const char* what(void) = 0;
  virtual int connect(const char* device, long baudrate) = 0;
  virtual void disconnect(void) = 0;
  virtual bool isConnected(void) = 0;
  virtual int changeBaudrate(long baudrate) = 0;
  virtual int send(const char* data, int size) = 0;
  virtual int recv(char* data, int size, int timeout) = 0;
  virtual int size(void) = 0;
  virtual void clear(void) = 0;
  virtual void skip(int timeout) = 0;
};

#endif /* !CONNECTION_INTERFACE_H */
